import "core-js/modules/es.array.concat.js";
import "core-js/modules/es.array.map.js";
import "core-js/modules/es.function.name.js";
import "core-js/modules/es.object.assign.js";

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import ComponentsList from 'rsg-components/ComponentsList';
import TableOfContentsRenderer from 'rsg-components/TableOfContents/TableOfContentsRenderer';
import filterSectionsByName from '../../utils/filterSectionsByName';
import filterComponentsByName from '../../utils/filterComponentsByName';
import { getHash } from '../../utils/handleHash';
import { getSectionUrl } from '../../utils/getUrl';

var TableOfContents = /*#__PURE__*/function (_Component) {
  _inheritsLoose(TableOfContents, _Component);

  function TableOfContents() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _Component.call.apply(_Component, [this].concat(args)) || this;

    _defineProperty(_assertThisInitialized(_this), "state", {
      searchTerm: ''
    });

    return _this;
  }

  var _proto = TableOfContents.prototype;

  _proto.renderLevel = function renderLevel(allSectionsAndComponents, pagePerSection, hashPath, // TODO: WTF is this?!
  useHashId) {
    var _this2 = this;

    if (pagePerSection === void 0) {
      pagePerSection = false;
    }

    if (hashPath === void 0) {
      hashPath = [];
    }

    if (useHashId === void 0) {
      useHashId = false;
    }

    // TODO: Highlight the first section/component by default with pagePerSection
    // Match selected component in both basic routing and pagePerSection routing.
    var _this$props$loc = this.props.loc,
        hash = _this$props$loc.hash,
        pathname = _this$props$loc.pathname;
    var windowHash = pathname + (pagePerSection ? hash : getHash(hash));
    var childrenContainSelected = false;
    var processedItems = allSectionsAndComponents.map(function (tocItem) {
      var components = 'components' in tocItem ? tocItem.components : [];
      var sections = 'sections' in tocItem ? tocItem.sections : [];
      var children = [].concat(components, sections);
      var sectionDepth = 'sectionDepth' in tocItem ? tocItem.sectionDepth || 0 : 0;
      var childHashPath = sectionDepth === 0 && useHashId ? hashPath : // TODO: Not sure we need the variant with the `-`
      [].concat(hashPath, [tocItem.name ? tocItem.name : '-']);

      var _ref = children.length > 0 ? _this2.renderLevel(children, pagePerSection, childHashPath, sectionDepth === 0) : {
        content: undefined,
        containsSelected: false
      },
          content = _ref.content,
          containsSelected = _ref.containsSelected;

      var selected = (!pagePerSection && tocItem.href ? getHash(tocItem.href) : tocItem.href) === windowHash;

      if (containsSelected || selected) {
        childrenContainSelected = true;
      }

      return Object.assign({}, tocItem, {
        components: components,
        sections: sections,
        content: content,
        selected: selected,
        href: tocItem.href || getSectionUrl({
          pagePerSection: pagePerSection,
          slug: tocItem.slug,
          hashPath: tocItem.hashPath
        }),
        // TODO: Rename to hasHeading
        heading: !!tocItem.name && children.length > 0,
        shouldOpenInNewTab: !!('external' in tocItem && tocItem.external) && !!('externalLink' in tocItem && tocItem.externalLink),
        // TODO: Rename to isInitiallyOpen
        initialOpen: _this2.props.tocMode !== 'collapse' || containsSelected || 'expand' in tocItem && tocItem.expand || false,
        // TODO: Rename to isForcedToOpen (?)
        forcedOpen: _this2.state.searchTerm.length > 0
      });
    });
    return {
      content: /*#__PURE__*/React.createElement(ComponentsList, {
        items: processedItems
      }),
      containsSelected: childrenContainSelected
    };
  };

  _proto.renderSections = function renderSections() {
    var searchTerm = this.state.searchTerm;
    var _this$props = this.props,
        sections = _this$props.sections,
        pagePerSection = _this$props.pagePerSection; // If there is only one section, we treat it as a root section
    // In this case the name of the section won't be rendered and it won't get left padding
    // Since a section can contain only other sections,
    // we need to make sure not to loose the subsections.
    // We will treat those subsections as the new roots.
    // TODO: Extract into a function

    var filtered = sections.length === 1 ? // only use subsections if there actually are subsections
    sections[0].sections.length > 0 ? filterSectionsByName(sections[0].sections, searchTerm) : filterComponentsByName(sections[0].components, searchTerm) : filterSectionsByName(sections, searchTerm);
    return this.renderLevel(filtered, pagePerSection).content;
  };

  _proto.render = function render() {
    var _this3 = this;

    var handleSearchTermChange = function handleSearchTermChange(searchTerm) {
      return _this3.setState({
        searchTerm: searchTerm
      });
    };

    return /*#__PURE__*/React.createElement(TableOfContentsRenderer, {
      searchTerm: this.state.searchTerm,
      onSearchTermChange: handleSearchTermChange
    }, this.renderSections());
  };

  return TableOfContents;
}(Component);

_defineProperty(TableOfContents, "propTypes", {
  sections: PropTypes.array.isRequired,
  pagePerSection: PropTypes.bool,
  tocMode: PropTypes.string,
  loc: PropTypes.object
});

_defineProperty(TableOfContents, "defaultProps", {
  loc: window.location
});

export { TableOfContents as default };