import "core-js/modules/es.array.map.js";
import "core-js/modules/es.function.name.js";
import "core-js/modules/es.array.filter.js";
import "core-js/modules/es.array.concat.js";
import "core-js/modules/es.object.assign.js";
import processComponents from './processComponents';
/**
 * Recursively process each component in all sections.
 */

export default function processSections(sections, parentHashPath) {
  if (parentHashPath === void 0) {
    parentHashPath = [];
  }

  return sections.map(function (section) {
    // Section without a name is a wrapper section: it's created when the user
    // uses `components` config option but not `section`. This section contains
    // components from the `components` config option but it's not rendered
    // in the UI, that's why it has no name and we should skip it when we generate
    // links to components in this section
    var name = section.name || '';
    var hashPath = [].concat(parentHashPath, [name]).filter(Boolean);
    return Object.assign({}, section, {
      name: name,
      visibleName: name,
      hashPath: hashPath,
      // Flag the section as an external link to avoid rendering it later
      externalLink: !!section.href,
      components: processComponents(section.components || [], hashPath),
      sections: processSections(section.sections || [], hashPath)
    });
  });
}